infer_timezone

Function infer_timezone 

pub fn infer_timezone(
    creation_time_utc: &DateTime<Utc>,
    filename: Option<&str>,
) -> Result<DateTime<FixedOffset>>
Attempt to parse a filename to set the correct timezone.

Strand Camera (and its predecessors) have saved times in UTC but set filenames based on the local time. This allows us to infer the timezone offset from UTC at the time the file was recorded without losing the UTC time. Here attempt to do this.